@@ -48,9 +48,8 @@ sub decode {
     # Storable doesn't take Unicode strings.
     Encode::_utf8_off($$value_ref);
 
-    local $@;
     $Storable::Eval = 1;
-    $$value_ref = eval { ${ Storable::thaw($$value_ref) } };
+    $$value_ref = ${ Storable::thaw($$value_ref) };
 }
 
 =head1 SEE ALSO
