@@ -40,7 +40,7 @@ associations between classes.
 use Carp qw/croak carp/;
 use Exporter::Lite;
 our @EXPORT
-    = qw(column type default validator immutable unreadable length distinct mandatory not_null sort_order valid_values label hints render_as since input_filters output_filters filters virtual is by are on);
+    = qw(column type default literal validator immutable unreadable length distinct mandatory not_null sort_order valid_values label hints render_as since input_filters output_filters filters virtual is by are on);
 
 our $SCHEMA;
 our $SORT_ORDERS = {};
@@ -89,17 +89,19 @@ sub column {
 
         if ( UNIVERSAL::isa( $refclass, 'Jifty::DBI::Record' ) ) {
             if ( $name =~ /(.*)_id$/ ) {
-                my $virtual_column = $from->add_column($1);
+                my $aliased_as = $1;
+                my $virtual_column = $from->add_column($aliased_as);
 
                 # XXX FIXME I think the next line is wrong, but things
                 # explode without it -- mostly because we unique-key
                 # on name instead of some conbination of name and
                 # alias_for_column in a couple places
                 $virtual_column->name( $name );
-
+                $virtual_column->aliased_as($aliased_as);
                 $_->apply($virtual_column) for @args;
                 $column->refers_to(undef);
                 $virtual_column->alias_for_column($name);
+                $from->_init_methods_for_column($virtual_column);
             }
             $column->by('id') unless $column->by;
             $column->type('integer') unless $column->type;
@@ -115,6 +117,7 @@ sub column {
 
 
     $from->COLUMNS->{$name} = $column;
+    $from->_init_methods_for_column($column);
 }
 
 =head2 type
@@ -139,6 +142,19 @@ sub default {
     _list( default => @_ );
 }
 
+=head2 literal
+
+Used for default values, to connote that they should not be quoted
+before being supplied as the default value for the column.  Correct
+usage is C<default is literal 'now()'>.
+
+=cut
+
+sub literal($) {
+    my $value = shift;
+    return \$value;
+}
+
 =head2 validator
 
 Defines a subroutine which returns a true value only for valid values
